@@ -11,6 +11,7 @@ theclimbinghangar.com
 #include "about.h"
 #include "help.h"
 #include "settings.h"
+#include "training.h"
 
 #include <QProcess>
 #include <QtCore/QCoreApplication>
@@ -473,6 +474,20 @@ void MainWindow::on_actionHelp_triggered()
     help->show();
 }
 
+void MainWindow::on_actionTraining_triggered()
+{
+    refreshTimer->stop();
+    preTimer->stop();
+    timersStop();
+    ui->lcdNumber->display("CEa5E");
+    ui->pushButtonStart->setDisabled(false);
+    ui->pushButtonStop->setDisabled(true);
+    ui->labelGif->setPixmap(QPixmap("/opt/tenminutecore/gif/blank.gif"));
+    ui->labelText->setText("-");
+    training = new Training(this);
+    training->show();
+}
+
 void MainWindow::on_actionSettings_triggered()
 {
     m_settings->show();
